X-Git-Url: https://git.rapsys.eu/userbundle/blobdiff_plain/737374b8cf79d853c2701b72b0a0a56f2ab3de35..680d677e18cf452174ae266f81a2856c5bd5b322:/Entity/User.php

diff --git a/Entity/User.php b/Entity/User.php
index 8286e55..5df315a 100644
--- a/Entity/User.php
+++ b/Entity/User.php
@@ -6,7 +6,7 @@ namespace Rapsys\UserBundle\Entity;
 use Rapsys\UserBundle\Entity\Group;
 use Symfony\Component\Security\Core\User\UserInterface;
 use Doctrine\Common\Collections\ArrayCollection;
-use Rapsys\UserBundle\Entity\Title;
+use Rapsys\UserBundle\Entity\Civility;
 
 class User implements UserInterface, \Serializable {
 	/**
@@ -44,6 +44,11 @@ class User implements UserInterface, \Serializable {
 	 */
 	protected $active;
 
+	/**
+	 * @var bool
+	 */
+	protected $disabled;
+
 	/**
 	 * @var \DateTime
 	 */
@@ -55,12 +60,12 @@ class User implements UserInterface, \Serializable {
 	protected $updated;
 
 	/**
-	 * @var \Rapsys\UserBundle\Entity\Title
+	 * @var \Rapsys\UserBundle\Entity\Civility
 	 */
-	protected $title;
+	protected $civility;
 
 	/**
-	 * @var \Doctrine\Common\Collections\Collection
+	 * @var \Doctrine\Common\Collections\ArrayCollection
 	 */
 	protected $groups;
 
@@ -69,6 +74,7 @@ class User implements UserInterface, \Serializable {
 	 */
 	public function __construct() {
 		$this->active = false;
+		$this->disabled = false;
 		$this->groups = new ArrayCollection();
 	}
 
@@ -77,7 +83,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return integer
 	 */
-	public function getId() {
+	public function getId(): int {
 		return $this->id;
 	}
 
@@ -88,7 +94,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setMail($mail) {
+	public function setMail(string $mail) {
 		$this->mail = $mail;
 
 		return $this;
@@ -99,7 +105,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getMail() {
+	public function getMail(): ?string {
 		return $this->mail;
 	}
 
@@ -110,7 +116,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setPseudonym($pseudonym) {
+	public function setPseudonym(string $pseudonym) {
 		$this->pseudonym = $pseudonym;
 
 		return $this;
@@ -121,7 +127,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getPseudonym() {
+	public function getPseudonym(): ?string {
 		return $this->pseudonym;
 	}
 
@@ -132,7 +138,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setForename($forename) {
+	public function setForename(string $forename) {
 		$this->forename = $forename;
 
 		return $this;
@@ -143,7 +149,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getForename() {
+	public function getForename(): ?string {
 		return $this->forename;
 	}
 
@@ -154,7 +160,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setSurname($surname) {
+	public function setSurname(string $surname) {
 		$this->surname = $surname;
 
 		return $this;
@@ -165,7 +171,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getSurname() {
+	public function getSurname(): ?string {
 		return $this->surname;
 	}
 
@@ -176,7 +182,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setPassword($password) {
+	public function setPassword(string $password) {
 		$this->password = $password;
 
 		return $this;
@@ -189,7 +195,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return string
 	 */
-	public function getPassword() {
+	public function getPassword(): ?string {
 		return $this->password;
 	}
 
@@ -200,7 +206,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setActive($active) {
+	public function setActive(bool $active) {
 		$this->active = $active;
 
 		return $this;
@@ -211,10 +217,32 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return bool
 	 */
-	public function getActive() {
+	public function getActive(): bool {
 		return $this->active;
 	}
 
+	/**
+	 * Set disabled
+	 *
+	 * @param bool $disabled
+	 *
+	 * @return User
+	 */
+	public function setDisabled(bool $disabled) {
+		$this->disabled = $disabled;
+
+		return $this;
+	}
+
+	/**
+	 * Get disabled
+	 *
+	 * @return bool
+	 */
+	public function getDisabled(): bool {
+		return $this->disabled;
+	}
+
 	/**
 	 * Set created
 	 *
@@ -222,7 +250,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setCreated($created) {
+	public function setCreated(\DateTime $created) {
 		$this->created = $created;
 
 		return $this;
@@ -233,7 +261,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return \DateTime
 	 */
-	public function getCreated() {
+	public function getCreated(): \DateTime {
 		return $this->created;
 	}
 
@@ -244,7 +272,7 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return User
 	 */
-	public function setUpdated($updated) {
+	public function setUpdated(\DateTime $updated) {
 		$this->updated = $updated;
 
 		return $this;
@@ -255,24 +283,24 @@ class User implements UserInterface, \Serializable {
 	 *
 	 * @return \DateTime
 	 */
-	public function getUpdated() {
+	public function getUpdated(): \DateTime {
 		return $this->updated;
 	}
 
 	/**
-	 * Set title
+	 * Set civility
 	 */
-	public function setTitle(Title $title) {
-		$this->title = $title;
+	public function setCivility(Civility $civility) {
+		$this->civility = $civility;
 
 		return $this;
 	}
 
 	/**
-	 * Get title
+	 * Get civility
 	 */
-	public function getTitle(): Title {
-		return $this->title;
+	public function getCivility(): ?Civility {
+		return $this->civility;
 	}
 
 	/**
@@ -300,16 +328,16 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * Get groups
 	 *
-	 * @return \Doctrine\Common\Collections\Collection
+	 * @return \Doctrine\Common\Collections\ArrayCollection
 	 */
-	public function getGroups() {
+	public function getGroups(): ArrayCollection {
 		return $this->groups;
 	}
 
 	/**
 	 * {@inheritdoc}
 	 */
-	public function getRoles() {
+	public function getRoles(): array {
 		//Get the unique roles list by id
 		return array_unique(array_reduce(
 			//Cast groups as array
@@ -326,7 +354,10 @@ class User implements UserInterface, \Serializable {
 		));
 	}
 
-	public function getRole() {
+	/**
+	 * {@inheritdoc}
+	 */
+	public function getRole(): ?string {
 		//Retrieve roles
 		$roles = $this->getRoles();
 
@@ -353,7 +384,7 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * {@inheritdoc}
 	 */
-	public function getSalt() {
+	public function getSalt(): ?string {
 		//No salt required with bcrypt
 		return null;
 	}
@@ -361,14 +392,14 @@ class User implements UserInterface, \Serializable {
 	/**
 	 * {@inheritdoc}
 	 */
-	public function getUsername() {
+	public function getUsername(): string {
 		return $this->mail;
 	}
 
 	/**
 	 * {@inheritdoc}
 	 */
-	public function eraseCredentials() {}
+	public function eraseCredentials(): void {}
 
 	public function serialize(): string {
 		return serialize([
@@ -376,6 +407,7 @@ class User implements UserInterface, \Serializable {
 			$this->mail,
 			$this->password,
 			$this->active,
+			$this->disabled,
 			$this->created,
 			$this->updated
 		]);
@@ -387,22 +419,49 @@ class User implements UserInterface, \Serializable {
 			$this->mail,
 			$this->password,
 			$this->active,
+			$this->disabled,
 			$this->created,
 			$this->updated
 		) = unserialize($serialized);
 	}
 
-	//XXX: was from vendor/symfony/security-core/User/AdvancedUserInterface.php, see if it's used anymore
-	public function isEnabled() {
+	/**
+	 * Check if account is activated
+	 *
+	 * @xxx was from deprecated AdvancedUserInterface, see if it's used anymore
+	 * @see vendor/symfony/security-core/User/AdvancedUserInterface.php
+	 */
+	public function isActivated(): bool {
 		return $this->active;
 	}
 
+	/**
+	 * Check if account is disabled
+	 *
+	 * @xxx was from deprecated AdvancedUserInterface, see if it's used anymore
+	 * @see vendor/symfony/security-core/User/AdvancedUserInterface.php
+	 */
+	public function isDisabled(): bool {
+		return $this->disabled;
+	}
+
+	/**
+	 * {@inheritdoc}
+	 */
+	public function preUpdate(\Doctrine\ORM\Event\PreUpdateEventArgs $eventArgs) {
+		//Check that we have an user instance
+		if (($user = $eventArgs->getEntity()) instanceof User) {
+			//Set updated value
+			$user->setUpdated(new \DateTime('now'));
+		}
+	}
+
 	/**
 	 * Returns a string representation of the user
 	 *
 	 * @return string
 	 */
 	public function __toString(): string {
-		return $this->title.' '.$this->forename.' '.$this->surname;
+		return $this->civility.' '.$this->forename.' '.$this->surname;
 	}
 }